==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2alpha1CronJobListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2alpha1CronJobListFluent<A extends V2alpha1CronJobListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V2alpha1CronJob item);
    public A setToItems(int index,V2alpha1CronJob item);
    public A addToItems(V2alpha1CronJob... items);
    public A addAllToItems(Collection<V2alpha1CronJob> items);
    public A removeFromItems(V2alpha1CronJob... items);
    public A removeAllFromItems(Collection<V2alpha1CronJob> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V2alpha1CronJob> getItems();
    public List<V2alpha1CronJob> buildItems();
    public V2alpha1CronJob buildItem(int index);
    public V2alpha1CronJob buildFirstItem();
    public V2alpha1CronJob buildLastItem();
    public V2alpha1CronJob buildMatchingItem(io.kubernetes.client.fluent.Predicate<V2alpha1CronJobBuilder> predicate);
    public A withItems(List<V2alpha1CronJob> items);
    public A withItems(V2alpha1CronJob... items);
    public Boolean hasItems();
    public V2alpha1CronJobListFluent.ItemsNested<A> addNewItem();
    public V2alpha1CronJobListFluent.ItemsNested<A> addNewItemLike(V2alpha1CronJob item);
    public V2alpha1CronJobListFluent.ItemsNested<A> setNewItemLike(int index,V2alpha1CronJob item);
    public V2alpha1CronJobListFluent.ItemsNested<A> editItem(int index);
    public V2alpha1CronJobListFluent.ItemsNested<A> editFirstItem();
    public V2alpha1CronJobListFluent.ItemsNested<A> editLastItem();
    public V2alpha1CronJobListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V2alpha1CronJobBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> withNewMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V2alpha1CronJobListFluent.MetadataNested<A> editMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> editOrNewMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2alpha1CronJobFluent<V2alpha1CronJobListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V2alpha1CronJobListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2alpha1CronJobListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2alpha1CronJobListFluent<A extends V2alpha1CronJobListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V2alpha1CronJob item);
    public A setToItems(int index,V2alpha1CronJob item);
    public A addToItems(V2alpha1CronJob... items);
    public A addAllToItems(Collection<V2alpha1CronJob> items);
    public A removeFromItems(V2alpha1CronJob... items);
    public A removeAllFromItems(Collection<V2alpha1CronJob> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V2alpha1CronJob> getItems();
    public List<V2alpha1CronJob> buildItems();
    public V2alpha1CronJob buildItem(int index);
    public V2alpha1CronJob buildFirstItem();
    public V2alpha1CronJob buildLastItem();
    public V2alpha1CronJob buildMatchingItem(io.kubernetes.client.fluent.Predicate<V2alpha1CronJobBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V2alpha1CronJobBuilder> predicate);
    public A withItems(List<V2alpha1CronJob> items);
    public A withItems(V2alpha1CronJob... items);
    public Boolean hasItems();
    public V2alpha1CronJobListFluent.ItemsNested<A> addNewItem();
    public V2alpha1CronJobListFluent.ItemsNested<A> addNewItemLike(V2alpha1CronJob item);
    public V2alpha1CronJobListFluent.ItemsNested<A> setNewItemLike(int index,V2alpha1CronJob item);
    public V2alpha1CronJobListFluent.ItemsNested<A> editItem(int index);
    public V2alpha1CronJobListFluent.ItemsNested<A> editFirstItem();
    public V2alpha1CronJobListFluent.ItemsNested<A> editLastItem();
    public V2alpha1CronJobListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V2alpha1CronJobBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> withNewMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V2alpha1CronJobListFluent.MetadataNested<A> editMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> editOrNewMetadata();
    public V2alpha1CronJobListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2alpha1CronJobFluent<V2alpha1CronJobListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V2alpha1CronJobListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
